@@ -1,7 +1,7 @@
 #!/usr/bin/env python
 
 """
-Copyright (c) 2006-2019 sqlmap developers (http://sqlmap.org/)
+Copyright (c) 2006-2020 sqlmap developers (http://sqlmap.org/)
 See the file 'LICENSE' for copying permission
 """
 
@@ -41,11 +41,15 @@ from thirdparty.beautifulsoup.beautifulsoup import BeautifulSoup
 from thirdparty.six.moves import http_client as _http_client
 from thirdparty.six.moves import urllib as _urllib
 
-def crawl(target):
+def crawl(target, post=None, cookie=None):
+    if not target:
+        return
+
     try:
         visited = set()
         threadData = getCurrentThreadData()
         threadData.shared.value = OrderedSet()
+        threadData.shared.formsFound = False
 
         def crawlThread():
             threadData = getCurrentThreadData()
@@ -68,7 +72,7 @@ def crawl(target):
                 content = None
                 try:
                     if current:
-                        content = Request.getPage(url=current, crawling=True, raise404=False)[0]
+                        content = Request.getPage(url=current, post=post, cookie=None, crawling=True, raise404=False)[0]
                 except SqlmapConnectionException as ex:
                     errMsg = "connection exception detected ('%s'). skipping " % getSafeExString(ex)
                     errMsg += "URL '%s'" % current
@@ -94,6 +98,7 @@ def crawl(target):
                         tags = soup('a')
 
                         tags += re.finditer(r'(?i)\s(href|src)=["\'](?P<href>[^>"\']+)', content)
+                        tags += re.finditer(r'(?i)window\.open\(["\'](?P<href>[^)"\']+)["\']', content)
 
                         for tag in tags:
                             href = tag.get("href") if hasattr(tag, "get") else tag.group("href")
@@ -115,7 +120,7 @@ def crawl(target):
                                 if (extractRegexResult(r"\A[^?]+\.(?P<result>\w+)(\?|\Z)", url) or "").lower() not in CRAWL_EXCLUDE_EXTENSIONS:
                                     with kb.locks.value:
                                         threadData.shared.deeper.add(url)
-                                        if re.search(r"(.*?)\?(.+)", url):
+                                        if re.search(r"(.*?)\?(.+)", url) and not re.search(r"\?(v=)?\d+\Z", url) and not re.search(r"(?i)\.(js|css)(\?|\Z)", url):
                                             threadData.shared.value.add(url)
                     except UnicodeEncodeError:  # for non-HTML files
                         pass
@@ -123,7 +128,7 @@ def crawl(target):
                         pass
                     finally:
                         if conf.forms:
-                            findPageForms(content, current, False, True)
+                            threadData.shared.formsFound |= len(findPageForms(content, current, False, True)) > 0
 
                 if conf.verbose in (1, 2):
                     threadData.shared.count += 1
@@ -133,36 +138,44 @@ def crawl(target):
         threadData.shared.deeper = set()
         threadData.shared.unprocessed = set([target])
 
-        if not conf.sitemapUrl:
+        _ = re.sub(r"(?<!/)/(?!/).*", "", target)
+        if _:
+            if target.strip('/') != _.strip('/'):
+                threadData.shared.unprocessed.add(_)
+
+        if re.search(r"\?.*\b\w+=", target):
+            threadData.shared.value.add(target)
+
+        if kb.checkSitemap is None:
             message = "do you want to check for the existence of "
             message += "site's sitemap(.xml) [y/N] "
+            kb.checkSitemap = readInput(message, default='N', boolean=True)
 
-            if readInput(message, default='N', boolean=True):
-                found = True
-                items = None
-                url = _urllib.parse.urljoin(target, "/sitemap.xml")
-                try:
-                    items = parseSitemap(url)
-                except SqlmapConnectionException as ex:
-                    if "page not found" in getSafeExString(ex):
-                        found = False
-                        logger.warn("'sitemap.xml' not found")
-                except:
-                    pass
-                finally:
-                    if found:
-                        if items:
-                            for item in items:
-                                if re.search(r"(.*?)\?(.+)", item):
-                                    threadData.shared.value.add(item)
-                            if conf.crawlDepth > 1:
-                                threadData.shared.unprocessed.update(items)
-                        logger.info("%s links found" % ("no" if not items else len(items)))
+        if kb.checkSitemap:
+            found = True
+            items = None
+            url = _urllib.parse.urljoin(target, "/sitemap.xml")
+            try:
+                items = parseSitemap(url)
+            except SqlmapConnectionException as ex:
+                if "page not found" in getSafeExString(ex):
+                    found = False
+                    logger.warn("'sitemap.xml' not found")
+            except:
+                pass
+            finally:
+                if found:
+                    if items:
+                        for item in items:
+                            if re.search(r"(.*?)\?(.+)", item):
+                                threadData.shared.value.add(item)
+                        if conf.crawlDepth > 1:
+                            threadData.shared.unprocessed.update(items)
+                    logger.info("%s links found" % ("no" if not items else len(items)))
 
-        infoMsg = "starting crawler"
-        if conf.bulkFile:
-            infoMsg += " for target URL '%s'" % target
-        logger.info(infoMsg)
+        if not conf.bulkFile:
+            infoMsg = "starting crawler for target URL '%s'" % target
+            logger.info(infoMsg)
 
         for i in xrange(conf.crawlDepth):
             threadData.shared.count = 0
@@ -189,33 +202,38 @@ def crawl(target):
         clearConsoleLine(True)
 
         if not threadData.shared.value:
-            warnMsg = "no usable links found (with GET parameters)"
-            logger.warn(warnMsg)
+            if not (conf.forms and threadData.shared.formsFound):
+                warnMsg = "no usable links found (with GET parameters)"
+                if conf.forms:
+                    warnMsg += " or forms"
+                logger.warn(warnMsg)
         else:
             for url in threadData.shared.value:
                 kb.targets.add((urldecode(url, kb.pageEncoding), None, None, None, None))
 
-        if kb.normalizeCrawlingChoice is None:
-            message = "do you want to normalize "
-            message += "crawling results [Y/n] "
+        if kb.targets:
+            if kb.normalizeCrawlingChoice is None:
+                message = "do you want to normalize "
+                message += "crawling results [Y/n] "
 
-            kb.normalizeCrawlingChoice = readInput(message, default='Y', boolean=True)
+                kb.normalizeCrawlingChoice = readInput(message, default='Y', boolean=True)
 
-        if kb.normalizeCrawlingChoice:
-            seen = set()
-            results = OrderedSet()
+            if kb.normalizeCrawlingChoice:
+                seen = set()
+                results = OrderedSet()
 
-            for target in kb.targets:
-                match = re.search(r"/[^/?]*\?.*\Z", target[0])
-                if match:
-                    key = re.sub(r"=[^=&]*", "=", match.group(0))
-                    if key not in seen:
-                        results.add(target)
-                        seen.add(key)
+                for target in kb.targets:
+                    value = "%s%s%s" % (target[0], '&' if '?' in target[0] else '?', target[2] or "")
+                    match = re.search(r"/[^/?]*\?.+\Z", value)
+                    if match:
+                        key = re.sub(r"=[^=&]*", "=", match.group(0)).strip("&?")
+                        if '=' in key and key not in seen:
+                            results.add(target)
+                            seen.add(key)
 
-            kb.targets = results
+                kb.targets = results
 
-        storeResultsToFile(kb.targets)
+            storeResultsToFile(kb.targets)
 
 def storeResultsToFile(results):
     if not results:
